@@ -58,25 +58,20 @@ get_mallows_loglik <- function(
 
   pfun_values <- prepare_partition_function(metric, n_items)
 
-  loglik <- vapply(
-    X = seq_len(n_clusters),
-    FUN = function(g) {
-      -(alpha[g] / n_items * sum(get_rank_distance(
-        rankings = t(rankings),
-        rho = rho[g, ],
-        metric = metric
-      ) * observation_frequency) +
-        N * get_partition_function(
-          alpha = alpha[g], n_items = n_items, metric = metric, pfun_values
-        )) *
-        weights[[g]]
-    },
-    FUN.VALUE = numeric(1)
+  pp <- vapply(seq_len(n_clusters), function(g) {
+    weights[g] * exp(-alpha[g] / n_items * compute_rank_distance(rankings, rho[g, ],
+                                                                 metric = metric,
+                                                                 observation_frequency = observation_frequency
+    ) - get_partition_function(alpha = alpha[g], n_items = n_items, metric = metric, pfun_values))
+  },
+  FUN.VALUE = numeric(nrow(rankings))
   )
 
+  loglik <- sum(log(apply(pp, 1, sum)))
+
   if (!log) {
-    exp(sum(loglik))
+    exp(loglik)
   } else {
-    sum(loglik)
+    loglik
   }
 }
