@@ -1,6 +1,7 @@
 #include <RcppArmadillo.h>
-#include "leapandshift.h"
 #include "distances.h"
+#include "missing_data.h"
+#include "rank_proposal.h"
 
 using namespace arma;
 
@@ -60,29 +61,23 @@ arma::mat rmallows(
     // Check if the user has tried to stop the running
     if (t % 1000 == 0) Rcpp::checkUserInterrupt();
 
-    vec rho_proposal;
-    uvec indices;
-    double prob_backward, prob_forward;
-
     // Sample a proposal
-    leap_and_shift(rho_proposal, indices, prob_backward, prob_forward,
-                   rho_iter, leap_size, distfun);
-
-    distfun->update_leap_and_shift_indices(indices, n_items);
+    auto prop = std::make_unique<RhoLeapAndShift>(leap_size);
+    RankProposal rp = prop->propose(rho_iter);
 
     // Compute the distances to current and proposed ranks
-    double dist_new = distfun->d(rho0(indices), rho_proposal(indices));
-    double dist_old = distfun->d(rho0(indices), rho_iter(indices));
+    double dist_new = distfun->d(rho0, rp.rankings, rp.mutated_items);
+    double dist_old = distfun->d(rho0, rho_iter, rp.mutated_items);
 
     // Metropolis-Hastings ratio
     double ratio = - alpha0 / n_items * (dist_new - dist_old) +
-      std::log(prob_backward) - std::log(prob_forward);
+      std::log(rp.prob_backward) - std::log(rp.prob_forward);
 
     // Draw a uniform random number
     double u = std::log(R::runif(0, 1));
 
     if(ratio > u){
-      rho_iter = rho_proposal;
+      rho_iter = rp.rankings;
     }
 
     // Save every thinning'th iteration after burnin
